# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateRuleDetails(object):
    """
    Object used to create a rule.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateRuleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateRuleDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateRuleDetails.
        :type description: str

        :param is_enabled:
            The value to assign to the is_enabled property of this CreateRuleDetails.
        :type is_enabled: bool

        :param condition:
            The value to assign to the condition property of this CreateRuleDetails.
        :type condition: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateRuleDetails.
        :type compartment_id: str

        :param actions:
            The value to assign to the actions property of this CreateRuleDetails.
        :type actions: oci.events.models.ActionDetailsList

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateRuleDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateRuleDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'is_enabled': 'bool',
            'condition': 'str',
            'compartment_id': 'str',
            'actions': 'ActionDetailsList',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'is_enabled': 'isEnabled',
            'condition': 'condition',
            'compartment_id': 'compartmentId',
            'actions': 'actions',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._is_enabled = None
        self._condition = None
        self._compartment_id = None
        self._actions = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateRuleDetails.
        A string that describes the rule. It does not have to be unique, and you can change it. Avoid entering
        confidential information.


        :return: The display_name of this CreateRuleDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateRuleDetails.
        A string that describes the rule. It does not have to be unique, and you can change it. Avoid entering
        confidential information.


        :param display_name: The display_name of this CreateRuleDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateRuleDetails.
        A string that describes the details of the rule. It does not have to be unique, and you can change it. Avoid entering
        confidential information.


        :return: The description of this CreateRuleDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateRuleDetails.
        A string that describes the details of the rule. It does not have to be unique, and you can change it. Avoid entering
        confidential information.


        :param description: The description of this CreateRuleDetails.
        :type: str
        """
        self._description = description

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this CreateRuleDetails.
        Whether or not this rule is currently enabled.

        Example: `true`


        :return: The is_enabled of this CreateRuleDetails.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this CreateRuleDetails.
        Whether or not this rule is currently enabled.

        Example: `true`


        :param is_enabled: The is_enabled of this CreateRuleDetails.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def condition(self):
        """
        **[Required]** Gets the condition of this CreateRuleDetails.
        A filter that specifies the event that will trigger actions associated with this rule. A few
        important things to remember about filters:

        * Fields not mentioned in the condition are ignored. You can create a valid filter that matches
        all events with two curly brackets: `{}`

          For more examples, see
        `Matching Events with Filters`__.
        * For a condition with fields to match an event, the event must contain all the field names
        listed in the condition. Field names must appear in the condition with the same nesting
        structure used in the event.

          For a list of reference events, see
        `Services that Produce Events`__.
        * Rules apply to events in the compartment in which you create them and any child compartments.
        This means that a condition specified by a rule only matches events emitted from resources in
        the compartment or any of its child compartments.
        * Wildcard matching is supported with the asterisk (*) character.

          For examples of wildcard matching, see
        `Matching Events with Filters`__

        Example: `\\\"eventType\\\": \\\"com.oraclecloud.databaseservice.autonomous.database.backup.end\\\"`

        __ https://docs.cloud.oracle.com/iaas/Content/Events/Concepts/filterevents.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Events/Reference/eventsproducers.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Events/Concepts/filterevents.htm


        :return: The condition of this CreateRuleDetails.
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """
        Sets the condition of this CreateRuleDetails.
        A filter that specifies the event that will trigger actions associated with this rule. A few
        important things to remember about filters:

        * Fields not mentioned in the condition are ignored. You can create a valid filter that matches
        all events with two curly brackets: `{}`

          For more examples, see
        `Matching Events with Filters`__.
        * For a condition with fields to match an event, the event must contain all the field names
        listed in the condition. Field names must appear in the condition with the same nesting
        structure used in the event.

          For a list of reference events, see
        `Services that Produce Events`__.
        * Rules apply to events in the compartment in which you create them and any child compartments.
        This means that a condition specified by a rule only matches events emitted from resources in
        the compartment or any of its child compartments.
        * Wildcard matching is supported with the asterisk (*) character.

          For examples of wildcard matching, see
        `Matching Events with Filters`__

        Example: `\\\"eventType\\\": \\\"com.oraclecloud.databaseservice.autonomous.database.backup.end\\\"`

        __ https://docs.cloud.oracle.com/iaas/Content/Events/Concepts/filterevents.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Events/Reference/eventsproducers.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Events/Concepts/filterevents.htm


        :param condition: The condition of this CreateRuleDetails.
        :type: str
        """
        self._condition = condition

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateRuleDetails.
        The `OCID`__ of the compartment to which this rule belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateRuleDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateRuleDetails.
        The `OCID`__ of the compartment to which this rule belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateRuleDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def actions(self):
        """
        **[Required]** Gets the actions of this CreateRuleDetails.

        :return: The actions of this CreateRuleDetails.
        :rtype: oci.events.models.ActionDetailsList
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """
        Sets the actions of this CreateRuleDetails.

        :param actions: The actions of this CreateRuleDetails.
        :type: oci.events.models.ActionDetailsList
        """
        self._actions = actions

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateRuleDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. Exists for cross-compatibility only.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateRuleDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateRuleDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. Exists for cross-compatibility only.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateRuleDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateRuleDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateRuleDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateRuleDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateRuleDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UIProperties(object):
    """
    The UI properties of the object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UIProperties object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param coordinate_x:
            The value to assign to the coordinate_x property of this UIProperties.
        :type coordinate_x: float

        :param coordinate_y:
            The value to assign to the coordinate_y property of this UIProperties.
        :type coordinate_y: float

        """
        self.swagger_types = {
            'coordinate_x': 'float',
            'coordinate_y': 'float'
        }

        self.attribute_map = {
            'coordinate_x': 'coordinateX',
            'coordinate_y': 'coordinateY'
        }

        self._coordinate_x = None
        self._coordinate_y = None

    @property
    def coordinate_x(self):
        """
        Gets the coordinate_x of this UIProperties.
        The X coordinate of the object.


        :return: The coordinate_x of this UIProperties.
        :rtype: float
        """
        return self._coordinate_x

    @coordinate_x.setter
    def coordinate_x(self, coordinate_x):
        """
        Sets the coordinate_x of this UIProperties.
        The X coordinate of the object.


        :param coordinate_x: The coordinate_x of this UIProperties.
        :type: float
        """
        self._coordinate_x = coordinate_x

    @property
    def coordinate_y(self):
        """
        Gets the coordinate_y of this UIProperties.
        The Y coordinate of the object.


        :return: The coordinate_y of this UIProperties.
        :rtype: float
        """
        return self._coordinate_y

    @coordinate_y.setter
    def coordinate_y(self, coordinate_y):
        """
        Sets the coordinate_y of this UIProperties.
        The Y coordinate of the object.


        :param coordinate_y: The coordinate_y of this UIProperties.
        :type: float
        """
        self._coordinate_y = coordinate_y

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CrossConnect(object):
    """
    For use with Oracle Cloud Infrastructure FastConnect. A cross-connect represents a
    physical connection between an existing network and Oracle. Customers who are colocated
    with Oracle in a FastConnect location create and use cross-connects. For more
    information, see `FastConnect Overview`__.

    Oracle recommends you create each cross-connect in a
    :class:`CrossConnectGroup` so you can use link aggregation
    with the connection.

    **Note:** If you're a provider who is setting up a physical connection to Oracle so customers
    can use FastConnect over the connection, be aware that your connection is modeled the
    same way as a colocated customer's (with `CrossConnect` and `CrossConnectGroup` objects, and so on).

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm
    __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a CrossConnect.
    #: This constant has a value of "PENDING_CUSTOMER"
    LIFECYCLE_STATE_PENDING_CUSTOMER = "PENDING_CUSTOMER"

    #: A constant which can be used with the lifecycle_state property of a CrossConnect.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a CrossConnect.
    #: This constant has a value of "PROVISIONED"
    LIFECYCLE_STATE_PROVISIONED = "PROVISIONED"

    #: A constant which can be used with the lifecycle_state property of a CrossConnect.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a CrossConnect.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a CrossConnect.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    def __init__(self, **kwargs):
        """
        Initializes a new CrossConnect object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CrossConnect.
        :type compartment_id: str

        :param cross_connect_group_id:
            The value to assign to the cross_connect_group_id property of this CrossConnect.
        :type cross_connect_group_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CrossConnect.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CrossConnect.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CrossConnect.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this CrossConnect.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CrossConnect.
            Allowed values for this property are: "PENDING_CUSTOMER", "PROVISIONING", "PROVISIONED", "INACTIVE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param location_name:
            The value to assign to the location_name property of this CrossConnect.
        :type location_name: str

        :param port_name:
            The value to assign to the port_name property of this CrossConnect.
        :type port_name: str

        :param port_speed_shape_name:
            The value to assign to the port_speed_shape_name property of this CrossConnect.
        :type port_speed_shape_name: str

        :param customer_reference_name:
            The value to assign to the customer_reference_name property of this CrossConnect.
        :type customer_reference_name: str

        :param time_created:
            The value to assign to the time_created property of this CrossConnect.
        :type time_created: datetime

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'cross_connect_group_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'lifecycle_state': 'str',
            'location_name': 'str',
            'port_name': 'str',
            'port_speed_shape_name': 'str',
            'customer_reference_name': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'cross_connect_group_id': 'crossConnectGroupId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'location_name': 'locationName',
            'port_name': 'portName',
            'port_speed_shape_name': 'portSpeedShapeName',
            'customer_reference_name': 'customerReferenceName',
            'time_created': 'timeCreated'
        }

        self._compartment_id = None
        self._cross_connect_group_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._lifecycle_state = None
        self._location_name = None
        self._port_name = None
        self._port_speed_shape_name = None
        self._customer_reference_name = None
        self._time_created = None

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this CrossConnect.
        The OCID of the compartment containing the cross-connect group.


        :return: The compartment_id of this CrossConnect.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CrossConnect.
        The OCID of the compartment containing the cross-connect group.


        :param compartment_id: The compartment_id of this CrossConnect.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def cross_connect_group_id(self):
        """
        Gets the cross_connect_group_id of this CrossConnect.
        The OCID of the cross-connect group this cross-connect belongs to (if any).


        :return: The cross_connect_group_id of this CrossConnect.
        :rtype: str
        """
        return self._cross_connect_group_id

    @cross_connect_group_id.setter
    def cross_connect_group_id(self, cross_connect_group_id):
        """
        Sets the cross_connect_group_id of this CrossConnect.
        The OCID of the cross-connect group this cross-connect belongs to (if any).


        :param cross_connect_group_id: The cross_connect_group_id of this CrossConnect.
        :type: str
        """
        self._cross_connect_group_id = cross_connect_group_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CrossConnect.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CrossConnect.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CrossConnect.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CrossConnect.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CrossConnect.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CrossConnect.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CrossConnect.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CrossConnect.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CrossConnect.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CrossConnect.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CrossConnect.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CrossConnect.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        Gets the id of this CrossConnect.
        The cross-connect's Oracle ID (OCID).


        :return: The id of this CrossConnect.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CrossConnect.
        The cross-connect's Oracle ID (OCID).


        :param id: The id of this CrossConnect.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this CrossConnect.
        The cross-connect's current state.

        Allowed values for this property are: "PENDING_CUSTOMER", "PROVISIONING", "PROVISIONED", "INACTIVE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this CrossConnect.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this CrossConnect.
        The cross-connect's current state.


        :param lifecycle_state: The lifecycle_state of this CrossConnect.
        :type: str
        """
        allowed_values = ["PENDING_CUSTOMER", "PROVISIONING", "PROVISIONED", "INACTIVE", "TERMINATING", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def location_name(self):
        """
        Gets the location_name of this CrossConnect.
        The name of the FastConnect location where this cross-connect is installed.


        :return: The location_name of this CrossConnect.
        :rtype: str
        """
        return self._location_name

    @location_name.setter
    def location_name(self, location_name):
        """
        Sets the location_name of this CrossConnect.
        The name of the FastConnect location where this cross-connect is installed.


        :param location_name: The location_name of this CrossConnect.
        :type: str
        """
        self._location_name = location_name

    @property
    def port_name(self):
        """
        Gets the port_name of this CrossConnect.
        A string identifying the meet-me room port for this cross-connect.


        :return: The port_name of this CrossConnect.
        :rtype: str
        """
        return self._port_name

    @port_name.setter
    def port_name(self, port_name):
        """
        Sets the port_name of this CrossConnect.
        A string identifying the meet-me room port for this cross-connect.


        :param port_name: The port_name of this CrossConnect.
        :type: str
        """
        self._port_name = port_name

    @property
    def port_speed_shape_name(self):
        """
        Gets the port_speed_shape_name of this CrossConnect.
        The port speed for this cross-connect.

        Example: `10 Gbps`


        :return: The port_speed_shape_name of this CrossConnect.
        :rtype: str
        """
        return self._port_speed_shape_name

    @port_speed_shape_name.setter
    def port_speed_shape_name(self, port_speed_shape_name):
        """
        Sets the port_speed_shape_name of this CrossConnect.
        The port speed for this cross-connect.

        Example: `10 Gbps`


        :param port_speed_shape_name: The port_speed_shape_name of this CrossConnect.
        :type: str
        """
        self._port_speed_shape_name = port_speed_shape_name

    @property
    def customer_reference_name(self):
        """
        Gets the customer_reference_name of this CrossConnect.
        A reference name or identifier for the physical fiber connection that this cross-connect
        uses.


        :return: The customer_reference_name of this CrossConnect.
        :rtype: str
        """
        return self._customer_reference_name

    @customer_reference_name.setter
    def customer_reference_name(self, customer_reference_name):
        """
        Sets the customer_reference_name of this CrossConnect.
        A reference name or identifier for the physical fiber connection that this cross-connect
        uses.


        :param customer_reference_name: The customer_reference_name of this CrossConnect.
        :type: str
        """
        self._customer_reference_name = customer_reference_name

    @property
    def time_created(self):
        """
        Gets the time_created of this CrossConnect.
        The date and time the cross-connect was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this CrossConnect.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this CrossConnect.
        The date and time the cross-connect was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this CrossConnect.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Schedule(object):
    """
    Schedule for scheduled task.
    """

    #: A constant which can be used with the type property of a Schedule.
    #: This constant has a value of "FIXED_FREQUENCY"
    TYPE_FIXED_FREQUENCY = "FIXED_FREQUENCY"

    #: A constant which can be used with the type property of a Schedule.
    #: This constant has a value of "CRON"
    TYPE_CRON = "CRON"

    #: A constant which can be used with the misfire_policy property of a Schedule.
    #: This constant has a value of "RETRY_ONCE"
    MISFIRE_POLICY_RETRY_ONCE = "RETRY_ONCE"

    #: A constant which can be used with the misfire_policy property of a Schedule.
    #: This constant has a value of "RETRY_INDEFINITELY"
    MISFIRE_POLICY_RETRY_INDEFINITELY = "RETRY_INDEFINITELY"

    #: A constant which can be used with the misfire_policy property of a Schedule.
    #: This constant has a value of "SKIP"
    MISFIRE_POLICY_SKIP = "SKIP"

    def __init__(self, **kwargs):
        """
        Initializes a new Schedule object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.log_analytics.models.CronSchedule`
        * :class:`~oci.log_analytics.models.FixedFrequencySchedule`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this Schedule.
            Allowed values for this property are: "FIXED_FREQUENCY", "CRON", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param misfire_policy:
            The value to assign to the misfire_policy property of this Schedule.
            Allowed values for this property are: "RETRY_ONCE", "RETRY_INDEFINITELY", "SKIP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type misfire_policy: str

        :param time_of_first_execution:
            The value to assign to the time_of_first_execution property of this Schedule.
        :type time_of_first_execution: datetime

        """
        self.swagger_types = {
            'type': 'str',
            'misfire_policy': 'str',
            'time_of_first_execution': 'datetime'
        }

        self.attribute_map = {
            'type': 'type',
            'misfire_policy': 'misfirePolicy',
            'time_of_first_execution': 'timeOfFirstExecution'
        }

        self._type = None
        self._misfire_policy = None
        self._time_of_first_execution = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'CRON':
            return 'CronSchedule'

        if type == 'FIXED_FREQUENCY':
            return 'FixedFrequencySchedule'
        else:
            return 'Schedule'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this Schedule.
        Schedule type discriminator.

        Allowed values for this property are: "FIXED_FREQUENCY", "CRON", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this Schedule.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Schedule.
        Schedule type discriminator.


        :param type: The type of this Schedule.
        :type: str
        """
        allowed_values = ["FIXED_FREQUENCY", "CRON"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def misfire_policy(self):
        """
        Gets the misfire_policy of this Schedule.
        Schedule misfire retry policy.

        Allowed values for this property are: "RETRY_ONCE", "RETRY_INDEFINITELY", "SKIP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The misfire_policy of this Schedule.
        :rtype: str
        """
        return self._misfire_policy

    @misfire_policy.setter
    def misfire_policy(self, misfire_policy):
        """
        Sets the misfire_policy of this Schedule.
        Schedule misfire retry policy.


        :param misfire_policy: The misfire_policy of this Schedule.
        :type: str
        """
        allowed_values = ["RETRY_ONCE", "RETRY_INDEFINITELY", "SKIP"]
        if not value_allowed_none_or_none_sentinel(misfire_policy, allowed_values):
            misfire_policy = 'UNKNOWN_ENUM_VALUE'
        self._misfire_policy = misfire_policy

    @property
    def time_of_first_execution(self):
        """
        Gets the time_of_first_execution of this Schedule.
        The date and time the scheduled task should execute first time after create or update;
        thereafter the task will execute as specified in the schedule.


        :return: The time_of_first_execution of this Schedule.
        :rtype: datetime
        """
        return self._time_of_first_execution

    @time_of_first_execution.setter
    def time_of_first_execution(self, time_of_first_execution):
        """
        Sets the time_of_first_execution of this Schedule.
        The date and time the scheduled task should execute first time after create or update;
        thereafter the task will execute as specified in the schedule.


        :param time_of_first_execution: The time_of_first_execution of this Schedule.
        :type: datetime
        """
        self._time_of_first_execution = time_of_first_execution

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Indexes(object):
    """
    Indexes
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Indexes object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param end_index:
            The value to assign to the end_index property of this Indexes.
        :type end_index: int

        :param start_index:
            The value to assign to the start_index property of this Indexes.
        :type start_index: int

        """
        self.swagger_types = {
            'end_index': 'int',
            'start_index': 'int'
        }

        self.attribute_map = {
            'end_index': 'endIndex',
            'start_index': 'startIndex'
        }

        self._end_index = None
        self._start_index = None

    @property
    def end_index(self):
        """
        Gets the end_index of this Indexes.
        The end index.


        :return: The end_index of this Indexes.
        :rtype: int
        """
        return self._end_index

    @end_index.setter
    def end_index(self, end_index):
        """
        Sets the end_index of this Indexes.
        The end index.


        :param end_index: The end_index of this Indexes.
        :type: int
        """
        self._end_index = end_index

    @property
    def start_index(self):
        """
        Gets the start_index of this Indexes.
        The start index.


        :return: The start_index of this Indexes.
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """
        Sets the start_index of this Indexes.
        The start index.


        :param start_index: The start_index of this Indexes.
        :type: int
        """
        self._start_index = start_index

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .access_log_policy import AccessLogPolicy
from .anonymous_route_authorization_policy import AnonymousRouteAuthorizationPolicy
from .any_of_route_authorization_policy import AnyOfRouteAuthorizationPolicy
from .api import Api
from .api_collection import ApiCollection
from .api_specification import ApiSpecification
from .api_specification_logging_policies import ApiSpecificationLoggingPolicies
from .api_specification_request_policies import ApiSpecificationRequestPolicies
from .api_specification_route import ApiSpecificationRoute
from .api_specification_route_backend import ApiSpecificationRouteBackend
from .api_specification_route_request_policies import ApiSpecificationRouteRequestPolicies
from .api_specification_route_response_policies import ApiSpecificationRouteResponsePolicies
from .api_summary import ApiSummary
from .api_validation_detail import ApiValidationDetail
from .api_validation_details import ApiValidationDetails
from .api_validation_result import ApiValidationResult
from .api_validations import ApiValidations
from .authentication_only_route_authorization_policy import AuthenticationOnlyRouteAuthorizationPolicy
from .authentication_policy import AuthenticationPolicy
from .body_validation_request_policy import BodyValidationRequestPolicy
from .certificate import Certificate
from .certificate_collection import CertificateCollection
from .certificate_summary import CertificateSummary
from .change_api_compartment_details import ChangeApiCompartmentDetails
from .change_certificate_compartment_details import ChangeCertificateCompartmentDetails
from .change_deployment_compartment_details import ChangeDeploymentCompartmentDetails
from .change_gateway_compartment_details import ChangeGatewayCompartmentDetails
from .content_validation import ContentValidation
from .cors_policy import CorsPolicy
from .create_api_details import CreateApiDetails
from .create_certificate_details import CreateCertificateDetails
from .create_deployment_details import CreateDeploymentDetails
from .create_gateway_details import CreateGatewayDetails
from .create_sdk_details import CreateSdkDetails
from .custom_authentication_policy import CustomAuthenticationPolicy
from .deployment import Deployment
from .deployment_collection import DeploymentCollection
from .deployment_summary import DeploymentSummary
from .execution_log_policy import ExecutionLogPolicy
from .external_resp_cache import ExternalRespCache
from .filter_header_policy import FilterHeaderPolicy
from .filter_header_policy_item import FilterHeaderPolicyItem
from .filter_query_parameter_policy import FilterQueryParameterPolicy
from .filter_query_parameter_policy_item import FilterQueryParameterPolicyItem
from .fixed_ttl_response_cache_store_policy import FixedTTLResponseCacheStorePolicy
from .gateway import Gateway
from .gateway_collection import GatewayCollection
from .gateway_summary import GatewaySummary
from .http_backend import HTTPBackend
from .header_field_specification import HeaderFieldSpecification
from .header_transformation_policy import HeaderTransformationPolicy
from .header_validation_item import HeaderValidationItem
from .header_validation_request_policy import HeaderValidationRequestPolicy
from .ip_address import IpAddress
from .json_web_key import JsonWebKey
from .json_web_token_claim import JsonWebTokenClaim
from .jwt_authentication_policy import JwtAuthenticationPolicy
from .no_cache import NoCache
from .no_content_validation import NoContentValidation
from .oracle_function_backend import OracleFunctionBackend
from .pem_encoded_public_key import PemEncodedPublicKey
from .public_key_set import PublicKeySet
from .query_parameter_transformation_policy import QueryParameterTransformationPolicy
from .query_parameter_validation_item import QueryParameterValidationItem
from .query_parameter_validation_request_policy import QueryParameterValidationRequestPolicy
from .rate_limiting_policy import RateLimitingPolicy
from .remote_json_web_key_set import RemoteJsonWebKeySet
from .rename_header_policy import RenameHeaderPolicy
from .rename_header_policy_item import RenameHeaderPolicyItem
from .rename_query_parameter_policy import RenameQueryParameterPolicy
from .rename_query_parameter_policy_item import RenameQueryParameterPolicyItem
from .request_parameter_validation import RequestParameterValidation
from .response_cache_details import ResponseCacheDetails
from .response_cache_lookup_policy import ResponseCacheLookupPolicy
from .response_cache_resp_server import ResponseCacheRespServer
from .response_cache_store_policy import ResponseCacheStorePolicy
from .route_authorization_policy import RouteAuthorizationPolicy
from .sdk import Sdk
from .sdk_collection import SdkCollection
from .sdk_language_optional_parameters import SdkLanguageOptionalParameters
from .sdk_language_optional_parameters_allowed_value import SdkLanguageOptionalParametersAllowedValue
from .sdk_language_type_collection import SdkLanguageTypeCollection
from .sdk_language_type_summary import SdkLanguageTypeSummary
from .sdk_language_types import SdkLanguageTypes
from .sdk_summary import SdkSummary
from .set_header_policy import SetHeaderPolicy
from .set_header_policy_item import SetHeaderPolicyItem
from .set_query_parameter_policy import SetQueryParameterPolicy
from .set_query_parameter_policy_item import SetQueryParameterPolicyItem
from .simple_lookup_policy import SimpleLookupPolicy
from .static_public_key import StaticPublicKey
from .static_public_key_set import StaticPublicKeySet
from .stock_response_backend import StockResponseBackend
from .update_api_details import UpdateApiDetails
from .update_certificate_details import UpdateCertificateDetails
from .update_deployment_details import UpdateDeploymentDetails
from .update_gateway_details import UpdateGatewayDetails
from .update_sdk_details import UpdateSdkDetails
from .validation_request_policy import ValidationRequestPolicy
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log import WorkRequestLog
from .work_request_log_collection import WorkRequestLogCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for apigateway services.
apigateway_type_mapping = {
    "AccessLogPolicy": AccessLogPolicy,
    "AnonymousRouteAuthorizationPolicy": AnonymousRouteAuthorizationPolicy,
    "AnyOfRouteAuthorizationPolicy": AnyOfRouteAuthorizationPolicy,
    "Api": Api,
    "ApiCollection": ApiCollection,
    "ApiSpecification": ApiSpecification,
    "ApiSpecificationLoggingPolicies": ApiSpecificationLoggingPolicies,
    "ApiSpecificationRequestPolicies": ApiSpecificationRequestPolicies,
    "ApiSpecificationRoute": ApiSpecificationRoute,
    "ApiSpecificationRouteBackend": ApiSpecificationRouteBackend,
    "ApiSpecificationRouteRequestPolicies": ApiSpecificationRouteRequestPolicies,
    "ApiSpecificationRouteResponsePolicies": ApiSpecificationRouteResponsePolicies,
    "ApiSummary": ApiSummary,
    "ApiValidationDetail": ApiValidationDetail,
    "ApiValidationDetails": ApiValidationDetails,
    "ApiValidationResult": ApiValidationResult,
    "ApiValidations": ApiValidations,
    "AuthenticationOnlyRouteAuthorizationPolicy": AuthenticationOnlyRouteAuthorizationPolicy,
    "AuthenticationPolicy": AuthenticationPolicy,
    "BodyValidationRequestPolicy": BodyValidationRequestPolicy,
    "Certificate": Certificate,
    "CertificateCollection": CertificateCollection,
    "CertificateSummary": CertificateSummary,
    "ChangeApiCompartmentDetails": ChangeApiCompartmentDetails,
    "ChangeCertificateCompartmentDetails": ChangeCertificateCompartmentDetails,
    "ChangeDeploymentCompartmentDetails": ChangeDeploymentCompartmentDetails,
    "ChangeGatewayCompartmentDetails": ChangeGatewayCompartmentDetails,
    "ContentValidation": ContentValidation,
    "CorsPolicy": CorsPolicy,
    "CreateApiDetails": CreateApiDetails,
    "CreateCertificateDetails": CreateCertificateDetails,
    "CreateDeploymentDetails": CreateDeploymentDetails,
    "CreateGatewayDetails": CreateGatewayDetails,
    "CreateSdkDetails": CreateSdkDetails,
    "CustomAuthenticationPolicy": CustomAuthenticationPolicy,
    "Deployment": Deployment,
    "DeploymentCollection": DeploymentCollection,
    "DeploymentSummary": DeploymentSummary,
    "ExecutionLogPolicy": ExecutionLogPolicy,
    "ExternalRespCache": ExternalRespCache,
    "FilterHeaderPolicy": FilterHeaderPolicy,
    "FilterHeaderPolicyItem": FilterHeaderPolicyItem,
    "FilterQueryParameterPolicy": FilterQueryParameterPolicy,
    "FilterQueryParameterPolicyItem": FilterQueryParameterPolicyItem,
    "FixedTTLResponseCacheStorePolicy": FixedTTLResponseCacheStorePolicy,
    "Gateway": Gateway,
    "GatewayCollection": GatewayCollection,
    "GatewaySummary": GatewaySummary,
    "HTTPBackend": HTTPBackend,
    "HeaderFieldSpecification": HeaderFieldSpecification,
    "HeaderTransformationPolicy": HeaderTransformationPolicy,
    "HeaderValidationItem": HeaderValidationItem,
    "HeaderValidationRequestPolicy": HeaderValidationRequestPolicy,
    "IpAddress": IpAddress,
    "JsonWebKey": JsonWebKey,
    "JsonWebTokenClaim": JsonWebTokenClaim,
    "JwtAuthenticationPolicy": JwtAuthenticationPolicy,
    "NoCache": NoCache,
    "NoContentValidation": NoContentValidation,
    "OracleFunctionBackend": OracleFunctionBackend,
    "PemEncodedPublicKey": PemEncodedPublicKey,
    "PublicKeySet": PublicKeySet,
    "QueryParameterTransformationPolicy": QueryParameterTransformationPolicy,
    "QueryParameterValidationItem": QueryParameterValidationItem,
    "QueryParameterValidationRequestPolicy": QueryParameterValidationRequestPolicy,
    "RateLimitingPolicy": RateLimitingPolicy,
    "RemoteJsonWebKeySet": RemoteJsonWebKeySet,
    "RenameHeaderPolicy": RenameHeaderPolicy,
    "RenameHeaderPolicyItem": RenameHeaderPolicyItem,
    "RenameQueryParameterPolicy": RenameQueryParameterPolicy,
    "RenameQueryParameterPolicyItem": RenameQueryParameterPolicyItem,
    "RequestParameterValidation": RequestParameterValidation,
    "ResponseCacheDetails": ResponseCacheDetails,
    "ResponseCacheLookupPolicy": ResponseCacheLookupPolicy,
    "ResponseCacheRespServer": ResponseCacheRespServer,
    "ResponseCacheStorePolicy": ResponseCacheStorePolicy,
    "RouteAuthorizationPolicy": RouteAuthorizationPolicy,
    "Sdk": Sdk,
    "SdkCollection": SdkCollection,
    "SdkLanguageOptionalParameters": SdkLanguageOptionalParameters,
    "SdkLanguageOptionalParametersAllowedValue": SdkLanguageOptionalParametersAllowedValue,
    "SdkLanguageTypeCollection": SdkLanguageTypeCollection,
    "SdkLanguageTypeSummary": SdkLanguageTypeSummary,
    "SdkLanguageTypes": SdkLanguageTypes,
    "SdkSummary": SdkSummary,
    "SetHeaderPolicy": SetHeaderPolicy,
    "SetHeaderPolicyItem": SetHeaderPolicyItem,
    "SetQueryParameterPolicy": SetQueryParameterPolicy,
    "SetQueryParameterPolicyItem": SetQueryParameterPolicyItem,
    "SimpleLookupPolicy": SimpleLookupPolicy,
    "StaticPublicKey": StaticPublicKey,
    "StaticPublicKeySet": StaticPublicKeySet,
    "StockResponseBackend": StockResponseBackend,
    "UpdateApiDetails": UpdateApiDetails,
    "UpdateCertificateDetails": UpdateCertificateDetails,
    "UpdateDeploymentDetails": UpdateDeploymentDetails,
    "UpdateGatewayDetails": UpdateGatewayDetails,
    "UpdateSdkDetails": UpdateSdkDetails,
    "ValidationRequestPolicy": ValidationRequestPolicy,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLog": WorkRequestLog,
    "WorkRequestLogCollection": WorkRequestLogCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SentimentAspect(object):
    """
    Aspect object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SentimentAspect object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param offset:
            The value to assign to the offset property of this SentimentAspect.
        :type offset: int

        :param length:
            The value to assign to the length property of this SentimentAspect.
        :type length: int

        :param text:
            The value to assign to the text property of this SentimentAspect.
        :type text: str

        :param sentiment:
            The value to assign to the sentiment property of this SentimentAspect.
        :type sentiment: str

        :param scores:
            The value to assign to the scores property of this SentimentAspect.
        :type scores: dict(str, float)

        """
        self.swagger_types = {
            'offset': 'int',
            'length': 'int',
            'text': 'str',
            'sentiment': 'str',
            'scores': 'dict(str, float)'
        }

        self.attribute_map = {
            'offset': 'offset',
            'length': 'length',
            'text': 'text',
            'sentiment': 'sentiment',
            'scores': 'scores'
        }

        self._offset = None
        self._length = None
        self._text = None
        self._sentiment = None
        self._scores = None

    @property
    def offset(self):
        """
        Gets the offset of this SentimentAspect.
        The number of Unicode code points preceding this entity in the submitted text.


        :return: The offset of this SentimentAspect.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """
        Sets the offset of this SentimentAspect.
        The number of Unicode code points preceding this entity in the submitted text.


        :param offset: The offset of this SentimentAspect.
        :type: int
        """
        self._offset = offset

    @property
    def length(self):
        """
        Gets the length of this SentimentAspect.
        Length of text.


        :return: The length of this SentimentAspect.
        :rtype: int
        """
        return self._length

    @length.setter
    def length(self, length):
        """
        Sets the length of this SentimentAspect.
        Length of text.


        :param length: The length of this SentimentAspect.
        :type: int
        """
        self._length = length

    @property
    def text(self):
        """
        Gets the text of this SentimentAspect.
        Aspect text.


        :return: The text of this SentimentAspect.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this SentimentAspect.
        Aspect text.


        :param text: The text of this SentimentAspect.
        :type: str
        """
        self._text = text

    @property
    def sentiment(self):
        """
        Gets the sentiment of this SentimentAspect.
        The highest-score sentiment for the aspect text.


        :return: The sentiment of this SentimentAspect.
        :rtype: str
        """
        return self._sentiment

    @sentiment.setter
    def sentiment(self, sentiment):
        """
        Sets the sentiment of this SentimentAspect.
        The highest-score sentiment for the aspect text.


        :param sentiment: The sentiment of this SentimentAspect.
        :type: str
        """
        self._sentiment = sentiment

    @property
    def scores(self):
        """
        Gets the scores of this SentimentAspect.
        Scores for each sentiment.
        Example: \"{\\\"positive\\\": 1.0, \\\"negative\\\": 0.0}\"


        :return: The scores of this SentimentAspect.
        :rtype: dict(str, float)
        """
        return self._scores

    @scores.setter
    def scores(self, scores):
        """
        Sets the scores of this SentimentAspect.
        Scores for each sentiment.
        Example: \"{\\\"positive\\\": 1.0, \\\"negative\\\": 0.0}\"


        :param scores: The scores of this SentimentAspect.
        :type: dict(str, float)
        """
        self._scores = scores

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UserAggregation(object):
    """
    The user aggregation provides information about the overall security state of database users.
    For example, it states how many users have the DBA role and how many users are in the critical category.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UserAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param items:
            The value to assign to the items property of this UserAggregation.
        :type items: list[dict(str, object)]

        """
        self.swagger_types = {
            'items': 'list[dict(str, object)]'
        }

        self.attribute_map = {
            'items': 'items'
        }

        self._items = None

    @property
    def items(self):
        """
        **[Required]** Gets the items of this UserAggregation.
        The array of user aggregation data.


        :return: The items of this UserAggregation.
        :rtype: list[dict(str, object)]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this UserAggregation.
        The array of user aggregation data.


        :param items: The items of this UserAggregation.
        :type: list[dict(str, object)]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FindingSummary(object):
    """
    The particular finding reported by the security assessment.
    """

    #: A constant which can be used with the severity property of a FindingSummary.
    #: This constant has a value of "HIGH"
    SEVERITY_HIGH = "HIGH"

    #: A constant which can be used with the severity property of a FindingSummary.
    #: This constant has a value of "MEDIUM"
    SEVERITY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the severity property of a FindingSummary.
    #: This constant has a value of "LOW"
    SEVERITY_LOW = "LOW"

    #: A constant which can be used with the severity property of a FindingSummary.
    #: This constant has a value of "EVALUATE"
    SEVERITY_EVALUATE = "EVALUATE"

    #: A constant which can be used with the severity property of a FindingSummary.
    #: This constant has a value of "ADVISORY"
    SEVERITY_ADVISORY = "ADVISORY"

    #: A constant which can be used with the severity property of a FindingSummary.
    #: This constant has a value of "PASS"
    SEVERITY_PASS = "PASS"

    def __init__(self, **kwargs):
        """
        Initializes a new FindingSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param severity:
            The value to assign to the severity property of this FindingSummary.
            Allowed values for this property are: "HIGH", "MEDIUM", "LOW", "EVALUATE", "ADVISORY", "PASS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type severity: str

        :param assessment_id:
            The value to assign to the assessment_id property of this FindingSummary.
        :type assessment_id: str

        :param target_id:
            The value to assign to the target_id property of this FindingSummary.
        :type target_id: str

        :param key:
            The value to assign to the key property of this FindingSummary.
        :type key: str

        :param title:
            The value to assign to the title property of this FindingSummary.
        :type title: str

        :param remarks:
            The value to assign to the remarks property of this FindingSummary.
        :type remarks: str

        :param details:
            The value to assign to the details property of this FindingSummary.
        :type details: object

        :param summary:
            The value to assign to the summary property of this FindingSummary.
        :type summary: str

        :param references:
            The value to assign to the references property of this FindingSummary.
        :type references: oci.data_safe.models.References

        """
        self.swagger_types = {
            'severity': 'str',
            'assessment_id': 'str',
            'target_id': 'str',
            'key': 'str',
            'title': 'str',
            'remarks': 'str',
            'details': 'object',
            'summary': 'str',
            'references': 'References'
        }

        self.attribute_map = {
            'severity': 'severity',
            'assessment_id': 'assessmentId',
            'target_id': 'targetId',
            'key': 'key',
            'title': 'title',
            'remarks': 'remarks',
            'details': 'details',
            'summary': 'summary',
            'references': 'references'
        }

        self._severity = None
        self._assessment_id = None
        self._target_id = None
        self._key = None
        self._title = None
        self._remarks = None
        self._details = None
        self._summary = None
        self._references = None

    @property
    def severity(self):
        """
        Gets the severity of this FindingSummary.
        The severity of the finding.

        Allowed values for this property are: "HIGH", "MEDIUM", "LOW", "EVALUATE", "ADVISORY", "PASS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The severity of this FindingSummary.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this FindingSummary.
        The severity of the finding.


        :param severity: The severity of this FindingSummary.
        :type: str
        """
        allowed_values = ["HIGH", "MEDIUM", "LOW", "EVALUATE", "ADVISORY", "PASS"]
        if not value_allowed_none_or_none_sentinel(severity, allowed_values):
            severity = 'UNKNOWN_ENUM_VALUE'
        self._severity = severity

    @property
    def assessment_id(self):
        """
        Gets the assessment_id of this FindingSummary.
        The OCID of the assessment that generated this finding.


        :return: The assessment_id of this FindingSummary.
        :rtype: str
        """
        return self._assessment_id

    @assessment_id.setter
    def assessment_id(self, assessment_id):
        """
        Sets the assessment_id of this FindingSummary.
        The OCID of the assessment that generated this finding.


        :param assessment_id: The assessment_id of this FindingSummary.
        :type: str
        """
        self._assessment_id = assessment_id

    @property
    def target_id(self):
        """
        Gets the target_id of this FindingSummary.
        The OCID of the target database.


        :return: The target_id of this FindingSummary.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this FindingSummary.
        The OCID of the target database.


        :param target_id: The target_id of this FindingSummary.
        :type: str
        """
        self._target_id = target_id

    @property
    def key(self):
        """
        Gets the key of this FindingSummary.
        The unique finding key. This is a system-generated identifier. To get the finding key for a finding, use ListFindings.


        :return: The key of this FindingSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this FindingSummary.
        The unique finding key. This is a system-generated identifier. To get the finding key for a finding, use ListFindings.


        :param key: The key of this FindingSummary.
        :type: str
        """
        self._key = key

    @property
    def title(self):
        """
        Gets the title of this FindingSummary.
        The short title for the finding.


        :return: The title of this FindingSummary.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this FindingSummary.
        The short title for the finding.


        :param title: The title of this FindingSummary.
        :type: str
        """
        self._title = title

    @property
    def remarks(self):
        """
        Gets the remarks of this FindingSummary.
        The explanation of the issue in this finding. It explains the reason for the rule and, if a risk is reported, it may also explain the recommended actions for remediation.


        :return: The remarks of this FindingSummary.
        :rtype: str
        """
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        """
        Sets the remarks of this FindingSummary.
        The explanation of the issue in this finding. It explains the reason for the rule and, if a risk is reported, it may also explain the recommended actions for remediation.


        :param remarks: The remarks of this FindingSummary.
        :type: str
        """
        self._remarks = remarks

    @property
    def details(self):
        """
        Gets the details of this FindingSummary.
        The details of the finding. Provides detailed information to explain the finding summary, typically results from the assessed database, followed by any recommendations for changes.


        :return: The details of this FindingSummary.
        :rtype: object
        """
        return self._details

    @details.setter
    def details(self, details):
        """
        Sets the details of this FindingSummary.
        The details of the finding. Provides detailed information to explain the finding summary, typically results from the assessed database, followed by any recommendations for changes.


        :param details: The details of this FindingSummary.
        :type: object
        """
        self._details = details

    @property
    def summary(self):
        """
        Gets the summary of this FindingSummary.
        The brief summary of the finding. When the finding is informational, the summary typically reports only the number of data elements that were examined.


        :return: The summary of this FindingSummary.
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """
        Sets the summary of this FindingSummary.
        The brief summary of the finding. When the finding is informational, the summary typically reports only the number of data elements that were examined.


        :param summary: The summary of this FindingSummary.
        :type: str
        """
        self._summary = summary

    @property
    def references(self):
        """
        Gets the references of this FindingSummary.
        Provides information on whether the finding is related to a CIS Oracle Database Benchmark recommendation, a STIG rule, or a GDPR Article/Recital.


        :return: The references of this FindingSummary.
        :rtype: oci.data_safe.models.References
        """
        return self._references

    @references.setter
    def references(self, references):
        """
        Sets the references of this FindingSummary.
        Provides information on whether the finding is related to a CIS Oracle Database Benchmark recommendation, a STIG rule, or a GDPR Article/Recital.


        :param references: The references of this FindingSummary.
        :type: oci.data_safe.models.References
        """
        self._references = references

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .attach_catalog_private_endpoint_details import AttachCatalogPrivateEndpointDetails
from .attribute import Attribute
from .attribute_collection import AttributeCollection
from .attribute_summary import AttributeSummary
from .attribute_tag import AttributeTag
from .attribute_tag_collection import AttributeTagCollection
from .attribute_tag_summary import AttributeTagSummary
from .base_permissions_summary import BasePermissionsSummary
from .base_tag import BaseTag
from .base_tag_summary import BaseTagSummary
from .catalog import Catalog
from .catalog_permissions_summary import CatalogPermissionsSummary
from .catalog_private_endpoint import CatalogPrivateEndpoint
from .catalog_private_endpoint_summary import CatalogPrivateEndpointSummary
from .catalog_summary import CatalogSummary
from .change_catalog_compartment_details import ChangeCatalogCompartmentDetails
from .change_catalog_private_endpoint_compartment_details import ChangeCatalogPrivateEndpointCompartmentDetails
from .change_metastore_compartment_details import ChangeMetastoreCompartmentDetails
from .connection import Connection
from .connection_alias_summary import ConnectionAliasSummary
from .connection_collection import ConnectionCollection
from .connection_summary import ConnectionSummary
from .create_attribute_details import CreateAttributeDetails
from .create_catalog_details import CreateCatalogDetails
from .create_catalog_private_endpoint_details import CreateCatalogPrivateEndpointDetails
from .create_connection_details import CreateConnectionDetails
from .create_custom_property_details import CreateCustomPropertyDetails
from .create_data_asset_details import CreateDataAssetDetails
from .create_entity_details import CreateEntityDetails
from .create_folder_details import CreateFolderDetails
from .create_glossary_details import CreateGlossaryDetails
from .create_job_definition_details import CreateJobDefinitionDetails
from .create_job_details import CreateJobDetails
from .create_job_execution_details import CreateJobExecutionDetails
from .create_metastore_details import CreateMetastoreDetails
from .create_namespace_details import CreateNamespaceDetails
from .create_pattern_details import CreatePatternDetails
from .create_tag_details import CreateTagDetails
from .create_term_details import CreateTermDetails
from .create_term_relationship_details import CreateTermRelationshipDetails
from .custom_property import CustomProperty
from .custom_property_collection import CustomPropertyCollection
from .custom_property_get_usage import CustomPropertyGetUsage
from .custom_property_set_usage import CustomPropertySetUsage
from .custom_property_summary import CustomPropertySummary
from .custom_property_type_usage import CustomPropertyTypeUsage
from .data_asset import DataAsset
from .data_asset_collection import DataAssetCollection
from .data_asset_export_scope import DataAssetExportScope
from .data_asset_permissions_summary import DataAssetPermissionsSummary
from .data_asset_summary import DataAssetSummary
from .data_asset_tag import DataAssetTag
from .data_asset_tag_collection import DataAssetTagCollection
from .data_asset_tag_summary import DataAssetTagSummary
from .data_selector_pattern_details import DataSelectorPatternDetails
from .derived_logical_entities import DerivedLogicalEntities
from .detach_catalog_private_endpoint_details import DetachCatalogPrivateEndpointDetails
from .entity import Entity
from .entity_collection import EntityCollection
from .entity_summary import EntitySummary
from .entity_tag import EntityTag
from .entity_tag_collection import EntityTagCollection
from .entity_tag_summary import EntityTagSummary
from .event_config import EventConfig
from .export_data_asset_details import ExportDataAssetDetails
from .faceted_search_aggregation import FacetedSearchAggregation
from .faceted_search_custom_property import FacetedSearchCustomProperty
from .faceted_search_date_filter_request import FacetedSearchDateFilterRequest
from .faceted_search_filter_request import FacetedSearchFilterRequest
from .faceted_search_sort_request import FacetedSearchSortRequest
from .faceted_search_string_filter_request import FacetedSearchStringFilterRequest
from .folder import Folder
from .folder_collection import FolderCollection
from .folder_summary import FolderSummary
from .folder_tag import FolderTag
from .folder_tag_collection import FolderTagCollection
from .folder_tag_summary import FolderTagSummary
from .glossary import Glossary
from .glossary_collection import GlossaryCollection
from .glossary_permissions_summary import GlossaryPermissionsSummary
from .glossary_summary import GlossarySummary
from .glossary_tree_element import GlossaryTreeElement
from .import_connection_details import ImportConnectionDetails
from .import_data_asset_details import ImportDataAssetDetails
from .import_data_asset_job_result import ImportDataAssetJobResult
from .import_glossary_details import ImportGlossaryDetails
from .job import Job
from .job_collection import JobCollection
from .job_definition import JobDefinition
from .job_definition_collection import JobDefinitionCollection
from .job_definition_permissions_summary import JobDefinitionPermissionsSummary
from .job_definition_scope import JobDefinitionScope
from .job_definition_summary import JobDefinitionSummary
from .job_execution import JobExecution
from .job_execution_collection import JobExecutionCollection
from .job_execution_summary import JobExecutionSummary
from .job_log import JobLog
from .job_log_collection import JobLogCollection
from .job_log_summary import JobLogSummary
from .job_metric import JobMetric
from .job_metric_collection import JobMetricCollection
from .job_metric_summary import JobMetricSummary
from .job_summary import JobSummary
from .metastore import Metastore
from .metastore_summary import MetastoreSummary
from .namespace import Namespace
from .namespace_collection import NamespaceCollection
from .namespace_summary import NamespaceSummary
from .object_relationship import ObjectRelationship
from .parse_connection_details import ParseConnectionDetails
from .pattern import Pattern
from .pattern_collection import PatternCollection
from .pattern_summary import PatternSummary
from .process_recommendation_details import ProcessRecommendationDetails
from .property_definition import PropertyDefinition
from .recommendation_collection import RecommendationCollection
from .recommendation_details import RecommendationDetails
from .rule_attribute import RuleAttribute
from .rule_collection import RuleCollection
from .rule_summary import RuleSummary
from .search_criteria import SearchCriteria
from .search_result import SearchResult
from .search_result_collection import SearchResultCollection
from .search_tag_summary import SearchTagSummary
from .search_term_summary import SearchTermSummary
from .suggest_list_item import SuggestListItem
from .suggest_results import SuggestResults
from .term import Term
from .term_associated_object import TermAssociatedObject
from .term_collection import TermCollection
from .term_relationship import TermRelationship
from .term_relationship_collection import TermRelationshipCollection
from .term_relationship_summary import TermRelationshipSummary
from .term_summary import TermSummary
from .type import Type
from .type_collection import TypeCollection
from .type_custom_property_details import TypeCustomPropertyDetails
from .type_summary import TypeSummary
from .update_attribute_details import UpdateAttributeDetails
from .update_catalog_details import UpdateCatalogDetails
from .update_catalog_private_endpoint_details import UpdateCatalogPrivateEndpointDetails
from .update_connection_details import UpdateConnectionDetails
from .update_custom_property_details import UpdateCustomPropertyDetails
from .update_data_asset_details import UpdateDataAssetDetails
from .update_entity_details import UpdateEntityDetails
from .update_folder_details import UpdateFolderDetails
from .update_glossary_details import UpdateGlossaryDetails
from .update_job_definition_details import UpdateJobDefinitionDetails
from .update_job_details import UpdateJobDetails
from .update_metastore_details import UpdateMetastoreDetails
from .update_namespace_details import UpdateNamespaceDetails
from .update_pattern_details import UpdatePatternDetails
from .update_term_details import UpdateTermDetails
from .update_term_relationship_details import UpdateTermRelationshipDetails
from .upload_credentials_details import UploadCredentialsDetails
from .validate_connection_details import ValidateConnectionDetails
from .validate_connection_result import ValidateConnectionResult
from .validate_pattern_details import ValidatePatternDetails
from .validate_pattern_result import ValidatePatternResult
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log import WorkRequestLog
from .work_request_resource import WorkRequestResource

# Maps type names to classes for data_catalog services.
data_catalog_type_mapping = {
    "AttachCatalogPrivateEndpointDetails": AttachCatalogPrivateEndpointDetails,
    "Attribute": Attribute,
    "AttributeCollection": AttributeCollection,
    "AttributeSummary": AttributeSummary,
    "AttributeTag": AttributeTag,
    "AttributeTagCollection": AttributeTagCollection,
    "AttributeTagSummary": AttributeTagSummary,
    "BasePermissionsSummary": BasePermissionsSummary,
    "BaseTag": BaseTag,
    "BaseTagSummary": BaseTagSummary,
    "Catalog": Catalog,
    "CatalogPermissionsSummary": CatalogPermissionsSummary,
    "CatalogPrivateEndpoint": CatalogPrivateEndpoint,
    "CatalogPrivateEndpointSummary": CatalogPrivateEndpointSummary,
    "CatalogSummary": CatalogSummary,
    "ChangeCatalogCompartmentDetails": ChangeCatalogCompartmentDetails,
    "ChangeCatalogPrivateEndpointCompartmentDetails": ChangeCatalogPrivateEndpointCompartmentDetails,
    "ChangeMetastoreCompartmentDetails": ChangeMetastoreCompartmentDetails,
    "Connection": Connection,
    "ConnectionAliasSummary": ConnectionAliasSummary,
    "ConnectionCollection": ConnectionCollection,
    "ConnectionSummary": ConnectionSummary,
    "CreateAttributeDetails": CreateAttributeDetails,
    "CreateCatalogDetails": CreateCatalogDetails,
    "CreateCatalogPrivateEndpointDetails": CreateCatalogPrivateEndpointDetails,
    "CreateConnectionDetails": CreateConnectionDetails,
    "CreateCustomPropertyDetails": CreateCustomPropertyDetails,
    "CreateDataAssetDetails": CreateDataAssetDetails,
    "CreateEntityDetails": CreateEntityDetails,
    "CreateFolderDetails": CreateFolderDetails,
    "CreateGlossaryDetails": CreateGlossaryDetails,
    "CreateJobDefinitionDetails": CreateJobDefinitionDetails,
    "CreateJobDetails": CreateJobDetails,
    "CreateJobExecutionDetails": CreateJobExecutionDetails,
    "CreateMetastoreDetails": CreateMetastoreDetails,
    "CreateNamespaceDetails": CreateNamespaceDetails,
    "CreatePatternDetails": CreatePatternDetails,
    "CreateTagDetails": CreateTagDetails,
    "CreateTermDetails": CreateTermDetails,
    "CreateTermRelationshipDetails": CreateTermRelationshipDetails,
    "CustomProperty": CustomProperty,
    "CustomPropertyCollection": CustomPropertyCollection,
    "CustomPropertyGetUsage": CustomPropertyGetUsage,
    "CustomPropertySetUsage": CustomPropertySetUsage,
    "CustomPropertySummary": CustomPropertySummary,
    "CustomPropertyTypeUsage": CustomPropertyTypeUsage,
    "DataAsset": DataAsset,
    "DataAssetCollection": DataAssetCollection,
    "DataAssetExportScope": DataAssetExportScope,
    "DataAssetPermissionsSummary": DataAssetPermissionsSummary,
    "DataAssetSummary": DataAssetSummary,
    "DataAssetTag": DataAssetTag,
    "DataAssetTagCollection": DataAssetTagCollection,
    "DataAssetTagSummary": DataAssetTagSummary,
    "DataSelectorPatternDetails": DataSelectorPatternDetails,
    "DerivedLogicalEntities": DerivedLogicalEntities,
    "DetachCatalogPrivateEndpointDetails": DetachCatalogPrivateEndpointDetails,
    "Entity": Entity,
    "EntityCollection": EntityCollection,
    "EntitySummary": EntitySummary,
    "EntityTag": EntityTag,
    "EntityTagCollection": EntityTagCollection,
    "EntityTagSummary": EntityTagSummary,
    "EventConfig": EventConfig,
    "ExportDataAssetDetails": ExportDataAssetDetails,
    "FacetedSearchAggregation": FacetedSearchAggregation,
    "FacetedSearchCustomProperty": FacetedSearchCustomProperty,
    "FacetedSearchDateFilterRequest": FacetedSearchDateFilterRequest,
    "FacetedSearchFilterRequest": FacetedSearchFilterRequest,
    "FacetedSearchSortRequest": FacetedSearchSortRequest,
    "FacetedSearchStringFilterRequest": FacetedSearchStringFilterRequest,
    "Folder": Folder,
    "FolderCollection": FolderCollection,
    "FolderSummary": FolderSummary,
    "FolderTag": FolderTag,
    "FolderTagCollection": FolderTagCollection,
    "FolderTagSummary": FolderTagSummary,
    "Glossary": Glossary,
    "GlossaryCollection": GlossaryCollection,
    "GlossaryPermissionsSummary": GlossaryPermissionsSummary,
    "GlossarySummary": GlossarySummary,
    "GlossaryTreeElement": GlossaryTreeElement,
    "ImportConnectionDetails": ImportConnectionDetails,
    "ImportDataAssetDetails": ImportDataAssetDetails,
    "ImportDataAssetJobResult": ImportDataAssetJobResult,
    "ImportGlossaryDetails": ImportGlossaryDetails,
    "Job": Job,
    "JobCollection": JobCollection,
    "JobDefinition": JobDefinition,
    "JobDefinitionCollection": JobDefinitionCollection,
    "JobDefinitionPermissionsSummary": JobDefinitionPermissionsSummary,
    "JobDefinitionScope": JobDefinitionScope,
    "JobDefinitionSummary": JobDefinitionSummary,
    "JobExecution": JobExecution,
    "JobExecutionCollection": JobExecutionCollection,
    "JobExecutionSummary": JobExecutionSummary,
    "JobLog": JobLog,
    "JobLogCollection": JobLogCollection,
    "JobLogSummary": JobLogSummary,
    "JobMetric": JobMetric,
    "JobMetricCollection": JobMetricCollection,
    "JobMetricSummary": JobMetricSummary,
    "JobSummary": JobSummary,
    "Metastore": Metastore,
    "MetastoreSummary": MetastoreSummary,
    "Namespace": Namespace,
    "NamespaceCollection": NamespaceCollection,
    "NamespaceSummary": NamespaceSummary,
    "ObjectRelationship": ObjectRelationship,
    "ParseConnectionDetails": ParseConnectionDetails,
    "Pattern": Pattern,
    "PatternCollection": PatternCollection,
    "PatternSummary": PatternSummary,
    "ProcessRecommendationDetails": ProcessRecommendationDetails,
    "PropertyDefinition": PropertyDefinition,
    "RecommendationCollection": RecommendationCollection,
    "RecommendationDetails": RecommendationDetails,
    "RuleAttribute": RuleAttribute,
    "RuleCollection": RuleCollection,
    "RuleSummary": RuleSummary,
    "SearchCriteria": SearchCriteria,
    "SearchResult": SearchResult,
    "SearchResultCollection": SearchResultCollection,
    "SearchTagSummary": SearchTagSummary,
    "SearchTermSummary": SearchTermSummary,
    "SuggestListItem": SuggestListItem,
    "SuggestResults": SuggestResults,
    "Term": Term,
    "TermAssociatedObject": TermAssociatedObject,
    "TermCollection": TermCollection,
    "TermRelationship": TermRelationship,
    "TermRelationshipCollection": TermRelationshipCollection,
    "TermRelationshipSummary": TermRelationshipSummary,
    "TermSummary": TermSummary,
    "Type": Type,
    "TypeCollection": TypeCollection,
    "TypeCustomPropertyDetails": TypeCustomPropertyDetails,
    "TypeSummary": TypeSummary,
    "UpdateAttributeDetails": UpdateAttributeDetails,
    "UpdateCatalogDetails": UpdateCatalogDetails,
    "UpdateCatalogPrivateEndpointDetails": UpdateCatalogPrivateEndpointDetails,
    "UpdateConnectionDetails": UpdateConnectionDetails,
    "UpdateCustomPropertyDetails": UpdateCustomPropertyDetails,
    "UpdateDataAssetDetails": UpdateDataAssetDetails,
    "UpdateEntityDetails": UpdateEntityDetails,
    "UpdateFolderDetails": UpdateFolderDetails,
    "UpdateGlossaryDetails": UpdateGlossaryDetails,
    "UpdateJobDefinitionDetails": UpdateJobDefinitionDetails,
    "UpdateJobDetails": UpdateJobDetails,
    "UpdateMetastoreDetails": UpdateMetastoreDetails,
    "UpdateNamespaceDetails": UpdateNamespaceDetails,
    "UpdatePatternDetails": UpdatePatternDetails,
    "UpdateTermDetails": UpdateTermDetails,
    "UpdateTermRelationshipDetails": UpdateTermRelationshipDetails,
    "UploadCredentialsDetails": UploadCredentialsDetails,
    "ValidateConnectionDetails": ValidateConnectionDetails,
    "ValidateConnectionResult": ValidateConnectionResult,
    "ValidatePatternDetails": ValidatePatternDetails,
    "ValidatePatternResult": ValidatePatternResult,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLog": WorkRequestLog,
    "WorkRequestResource": WorkRequestResource
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PostMetricDataDetails(object):
    """
    An array of metric objects containing raw metric data points to be posted to the Monitoring service.
    """

    #: A constant which can be used with the batch_atomicity property of a PostMetricDataDetails.
    #: This constant has a value of "ATOMIC"
    BATCH_ATOMICITY_ATOMIC = "ATOMIC"

    #: A constant which can be used with the batch_atomicity property of a PostMetricDataDetails.
    #: This constant has a value of "NON_ATOMIC"
    BATCH_ATOMICITY_NON_ATOMIC = "NON_ATOMIC"

    def __init__(self, **kwargs):
        """
        Initializes a new PostMetricDataDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_data:
            The value to assign to the metric_data property of this PostMetricDataDetails.
        :type metric_data: list[oci.monitoring.models.MetricDataDetails]

        :param batch_atomicity:
            The value to assign to the batch_atomicity property of this PostMetricDataDetails.
            Allowed values for this property are: "ATOMIC", "NON_ATOMIC"
        :type batch_atomicity: str

        """
        self.swagger_types = {
            'metric_data': 'list[MetricDataDetails]',
            'batch_atomicity': 'str'
        }

        self.attribute_map = {
            'metric_data': 'metricData',
            'batch_atomicity': 'batchAtomicity'
        }

        self._metric_data = None
        self._batch_atomicity = None

    @property
    def metric_data(self):
        """
        **[Required]** Gets the metric_data of this PostMetricDataDetails.
        A metric object containing raw metric data points to be posted to the Monitoring service.


        :return: The metric_data of this PostMetricDataDetails.
        :rtype: list[oci.monitoring.models.MetricDataDetails]
        """
        return self._metric_data

    @metric_data.setter
    def metric_data(self, metric_data):
        """
        Sets the metric_data of this PostMetricDataDetails.
        A metric object containing raw metric data points to be posted to the Monitoring service.


        :param metric_data: The metric_data of this PostMetricDataDetails.
        :type: list[oci.monitoring.models.MetricDataDetails]
        """
        self._metric_data = metric_data

    @property
    def batch_atomicity(self):
        """
        Gets the batch_atomicity of this PostMetricDataDetails.
        Batch atomicity behavior. Requires either partial or full pass of input validation for
        metric objects in PostMetricData requests. The default value of NON_ATOMIC requires a
        partial pass: at least one metric object in the request must pass input validation, and
        any objects that failed validation are identified in the returned summary, along with
        their error messages. A value of ATOMIC requires a full pass: all metric objects in
        the request must pass input validation.

        Example: `NON_ATOMIC`

        Allowed values for this property are: "ATOMIC", "NON_ATOMIC"


        :return: The batch_atomicity of this PostMetricDataDetails.
        :rtype: str
        """
        return self._batch_atomicity

    @batch_atomicity.setter
    def batch_atomicity(self, batch_atomicity):
        """
        Sets the batch_atomicity of this PostMetricDataDetails.
        Batch atomicity behavior. Requires either partial or full pass of input validation for
        metric objects in PostMetricData requests. The default value of NON_ATOMIC requires a
        partial pass: at least one metric object in the request must pass input validation, and
        any objects that failed validation are identified in the returned summary, along with
        their error messages. A value of ATOMIC requires a full pass: all metric objects in
        the request must pass input validation.

        Example: `NON_ATOMIC`


        :param batch_atomicity: The batch_atomicity of this PostMetricDataDetails.
        :type: str
        """
        allowed_values = ["ATOMIC", "NON_ATOMIC"]
        if not value_allowed_none_or_none_sentinel(batch_atomicity, allowed_values):
            raise ValueError(
                "Invalid value for `batch_atomicity`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._batch_atomicity = batch_atomicity

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateIPSecConnectionDetails(object):
    """
    CreateIPSecConnectionDetails model.
    """

    #: A constant which can be used with the cpe_local_identifier_type property of a CreateIPSecConnectionDetails.
    #: This constant has a value of "IP_ADDRESS"
    CPE_LOCAL_IDENTIFIER_TYPE_IP_ADDRESS = "IP_ADDRESS"

    #: A constant which can be used with the cpe_local_identifier_type property of a CreateIPSecConnectionDetails.
    #: This constant has a value of "HOSTNAME"
    CPE_LOCAL_IDENTIFIER_TYPE_HOSTNAME = "HOSTNAME"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateIPSecConnectionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateIPSecConnectionDetails.
        :type compartment_id: str

        :param cpe_id:
            The value to assign to the cpe_id property of this CreateIPSecConnectionDetails.
        :type cpe_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateIPSecConnectionDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateIPSecConnectionDetails.
        :type display_name: str

        :param drg_id:
            The value to assign to the drg_id property of this CreateIPSecConnectionDetails.
        :type drg_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateIPSecConnectionDetails.
        :type freeform_tags: dict(str, str)

        :param cpe_local_identifier:
            The value to assign to the cpe_local_identifier property of this CreateIPSecConnectionDetails.
        :type cpe_local_identifier: str

        :param cpe_local_identifier_type:
            The value to assign to the cpe_local_identifier_type property of this CreateIPSecConnectionDetails.
            Allowed values for this property are: "IP_ADDRESS", "HOSTNAME"
        :type cpe_local_identifier_type: str

        :param static_routes:
            The value to assign to the static_routes property of this CreateIPSecConnectionDetails.
        :type static_routes: list[str]

        :param tunnel_configuration:
            The value to assign to the tunnel_configuration property of this CreateIPSecConnectionDetails.
        :type tunnel_configuration: list[oci.core.models.CreateIPSecConnectionTunnelDetails]

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'cpe_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'drg_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'cpe_local_identifier': 'str',
            'cpe_local_identifier_type': 'str',
            'static_routes': 'list[str]',
            'tunnel_configuration': 'list[CreateIPSecConnectionTunnelDetails]'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'cpe_id': 'cpeId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'drg_id': 'drgId',
            'freeform_tags': 'freeformTags',
            'cpe_local_identifier': 'cpeLocalIdentifier',
            'cpe_local_identifier_type': 'cpeLocalIdentifierType',
            'static_routes': 'staticRoutes',
            'tunnel_configuration': 'tunnelConfiguration'
        }

        self._compartment_id = None
        self._cpe_id = None
        self._defined_tags = None
        self._display_name = None
        self._drg_id = None
        self._freeform_tags = None
        self._cpe_local_identifier = None
        self._cpe_local_identifier_type = None
        self._static_routes = None
        self._tunnel_configuration = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateIPSecConnectionDetails.
        The OCID of the compartment to contain the IPSec connection.


        :return: The compartment_id of this CreateIPSecConnectionDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateIPSecConnectionDetails.
        The OCID of the compartment to contain the IPSec connection.


        :param compartment_id: The compartment_id of this CreateIPSecConnectionDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def cpe_id(self):
        """
        **[Required]** Gets the cpe_id of this CreateIPSecConnectionDetails.
        The OCID of the :class:`Cpe` object.


        :return: The cpe_id of this CreateIPSecConnectionDetails.
        :rtype: str
        """
        return self._cpe_id

    @cpe_id.setter
    def cpe_id(self, cpe_id):
        """
        Sets the cpe_id of this CreateIPSecConnectionDetails.
        The OCID of the :class:`Cpe` object.


        :param cpe_id: The cpe_id of this CreateIPSecConnectionDetails.
        :type: str
        """
        self._cpe_id = cpe_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateIPSecConnectionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateIPSecConnectionDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateIPSecConnectionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateIPSecConnectionDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateIPSecConnectionDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateIPSecConnectionDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateIPSecConnectionDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateIPSecConnectionDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def drg_id(self):
        """
        **[Required]** Gets the drg_id of this CreateIPSecConnectionDetails.
        The `OCID`__ of the DRG.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The drg_id of this CreateIPSecConnectionDetails.
        :rtype: str
        """
        return self._drg_id

    @drg_id.setter
    def drg_id(self, drg_id):
        """
        Sets the drg_id of this CreateIPSecConnectionDetails.
        The `OCID`__ of the DRG.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param drg_id: The drg_id of this CreateIPSecConnectionDetails.
        :type: str
        """
        self._drg_id = drg_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateIPSecConnectionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateIPSecConnectionDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateIPSecConnectionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateIPSecConnectionDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def cpe_local_identifier(self):
        """
        Gets the cpe_local_identifier of this CreateIPSecConnectionDetails.
        Your identifier for your CPE device. Can be either an IP address or a hostname (specifically, the
        fully qualified domain name (FQDN)). The type of identifier you provide here must correspond
        to the value for `cpeLocalIdentifierType`.

        If you don't provide a value, the `ipAddress` attribute for the :class:`Cpe`
        object specified by `cpeId` is used as the `cpeLocalIdentifier`.

        For information about why you'd provide this value, see
        `If Your CPE Is Behind a NAT Device`__.

        Example IP address: `10.0.3.3`

        Example hostname: `cpe.example.com`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/overviewIPsec.htm#nat


        :return: The cpe_local_identifier of this CreateIPSecConnectionDetails.
        :rtype: str
        """
        return self._cpe_local_identifier

    @cpe_local_identifier.setter
    def cpe_local_identifier(self, cpe_local_identifier):
        """
        Sets the cpe_local_identifier of this CreateIPSecConnectionDetails.
        Your identifier for your CPE device. Can be either an IP address or a hostname (specifically, the
        fully qualified domain name (FQDN)). The type of identifier you provide here must correspond
        to the value for `cpeLocalIdentifierType`.

        If you don't provide a value, the `ipAddress` attribute for the :class:`Cpe`
        object specified by `cpeId` is used as the `cpeLocalIdentifier`.

        For information about why you'd provide this value, see
        `If Your CPE Is Behind a NAT Device`__.

        Example IP address: `10.0.3.3`

        Example hostname: `cpe.example.com`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/overviewIPsec.htm#nat


        :param cpe_local_identifier: The cpe_local_identifier of this CreateIPSecConnectionDetails.
        :type: str
        """
        self._cpe_local_identifier = cpe_local_identifier

    @property
    def cpe_local_identifier_type(self):
        """
        Gets the cpe_local_identifier_type of this CreateIPSecConnectionDetails.
        The type of identifier for your CPE device. The value you provide here must correspond to the value
        for `cpeLocalIdentifier`.

        Allowed values for this property are: "IP_ADDRESS", "HOSTNAME"


        :return: The cpe_local_identifier_type of this CreateIPSecConnectionDetails.
        :rtype: str
        """
        return self._cpe_local_identifier_type

    @cpe_local_identifier_type.setter
    def cpe_local_identifier_type(self, cpe_local_identifier_type):
        """
        Sets the cpe_local_identifier_type of this CreateIPSecConnectionDetails.
        The type of identifier for your CPE device. The value you provide here must correspond to the value
        for `cpeLocalIdentifier`.


        :param cpe_local_identifier_type: The cpe_local_identifier_type of this CreateIPSecConnectionDetails.
        :type: str
        """
        allowed_values = ["IP_ADDRESS", "HOSTNAME"]
        if not value_allowed_none_or_none_sentinel(cpe_local_identifier_type, allowed_values):
            raise ValueError(
                "Invalid value for `cpe_local_identifier_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._cpe_local_identifier_type = cpe_local_identifier_type

    @property
    def static_routes(self):
        """
        **[Required]** Gets the static_routes of this CreateIPSecConnectionDetails.
        Static routes to the CPE. A static route's CIDR must not be a
        multicast address or class E address.

        Used for routing a given IPSec tunnel's traffic only if the tunnel
        is using static routing. If you configure at least one tunnel to use static routing, then
        you must provide at least one valid static route. If you configure both
        tunnels to use BGP dynamic routing, you can provide an empty list for the static routes.
        For more information, see the important note in :class:`IPSecConnection`.

        The CIDR can be either IPv4 or IPv6. IPv6 addressing is supported for all commercial and government regions.
        See `IPv6 Addresses`__.

        Example: `10.0.1.0/24`

        Example: `2001:db8::/32`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :return: The static_routes of this CreateIPSecConnectionDetails.
        :rtype: list[str]
        """
        return self._static_routes

    @static_routes.setter
    def static_routes(self, static_routes):
        """
        Sets the static_routes of this CreateIPSecConnectionDetails.
        Static routes to the CPE. A static route's CIDR must not be a
        multicast address or class E address.

        Used for routing a given IPSec tunnel's traffic only if the tunnel
        is using static routing. If you configure at least one tunnel to use static routing, then
        you must provide at least one valid static route. If you configure both
        tunnels to use BGP dynamic routing, you can provide an empty list for the static routes.
        For more information, see the important note in :class:`IPSecConnection`.

        The CIDR can be either IPv4 or IPv6. IPv6 addressing is supported for all commercial and government regions.
        See `IPv6 Addresses`__.

        Example: `10.0.1.0/24`

        Example: `2001:db8::/32`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :param static_routes: The static_routes of this CreateIPSecConnectionDetails.
        :type: list[str]
        """
        self._static_routes = static_routes

    @property
    def tunnel_configuration(self):
        """
        Gets the tunnel_configuration of this CreateIPSecConnectionDetails.
        Information for creating the individual tunnels in the IPSec connection. You can provide a
        maximum of 2 `tunnelConfiguration` objects in the array (one for each of the
        two tunnels).


        :return: The tunnel_configuration of this CreateIPSecConnectionDetails.
        :rtype: list[oci.core.models.CreateIPSecConnectionTunnelDetails]
        """
        return self._tunnel_configuration

    @tunnel_configuration.setter
    def tunnel_configuration(self, tunnel_configuration):
        """
        Sets the tunnel_configuration of this CreateIPSecConnectionDetails.
        Information for creating the individual tunnels in the IPSec connection. You can provide a
        maximum of 2 `tunnelConfiguration` objects in the array (one for each of the
        two tunnels).


        :param tunnel_configuration: The tunnel_configuration of this CreateIPSecConnectionDetails.
        :type: list[oci.core.models.CreateIPSecConnectionTunnelDetails]
        """
        self._tunnel_configuration = tunnel_configuration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateTransferDeviceDetails(object):
    """
    CreateTransferDeviceDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateTransferDeviceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param serial_number:
            The value to assign to the serial_number property of this CreateTransferDeviceDetails.
        :type serial_number: str

        :param iscsi_iqn:
            The value to assign to the iscsi_iqn property of this CreateTransferDeviceDetails.
        :type iscsi_iqn: str

        """
        self.swagger_types = {
            'serial_number': 'str',
            'iscsi_iqn': 'str'
        }

        self.attribute_map = {
            'serial_number': 'serialNumber',
            'iscsi_iqn': 'iscsiIQN'
        }

        self._serial_number = None
        self._iscsi_iqn = None

    @property
    def serial_number(self):
        """
        Gets the serial_number of this CreateTransferDeviceDetails.

        :return: The serial_number of this CreateTransferDeviceDetails.
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """
        Sets the serial_number of this CreateTransferDeviceDetails.

        :param serial_number: The serial_number of this CreateTransferDeviceDetails.
        :type: str
        """
        self._serial_number = serial_number

    @property
    def iscsi_iqn(self):
        """
        Gets the iscsi_iqn of this CreateTransferDeviceDetails.

        :return: The iscsi_iqn of this CreateTransferDeviceDetails.
        :rtype: str
        """
        return self._iscsi_iqn

    @iscsi_iqn.setter
    def iscsi_iqn(self, iscsi_iqn):
        """
        Sets the iscsi_iqn of this CreateTransferDeviceDetails.

        :param iscsi_iqn: The iscsi_iqn of this CreateTransferDeviceDetails.
        :type: str
        """
        self._iscsi_iqn = iscsi_iqn

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SortKey(object):
    """
    Sort key contains a set of sort key rules defining sorting algorithm.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SortKey object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sort_rules:
            The value to assign to the sort_rules property of this SortKey.
        :type sort_rules: list[oci.data_integration.models.SortKeyRule]

        """
        self.swagger_types = {
            'sort_rules': 'list[SortKeyRule]'
        }

        self.attribute_map = {
            'sort_rules': 'sortRules'
        }

        self._sort_rules = None

    @property
    def sort_rules(self):
        """
        Gets the sort_rules of this SortKey.
        The list of sort key rules.


        :return: The sort_rules of this SortKey.
        :rtype: list[oci.data_integration.models.SortKeyRule]
        """
        return self._sort_rules

    @sort_rules.setter
    def sort_rules(self, sort_rules):
        """
        Sets the sort_rules of this SortKey.
        The list of sort key rules.


        :param sort_rules: The sort_rules of this SortKey.
        :type: list[oci.data_integration.models.SortKeyRule]
        """
        self._sort_rules = sort_rules

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TablespaceUsageTrendAggregation(object):
    """
    Usage data per tablespace for a Pluggable database
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TablespaceUsageTrendAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tablespace_name:
            The value to assign to the tablespace_name property of this TablespaceUsageTrendAggregation.
        :type tablespace_name: str

        :param tablespace_type:
            The value to assign to the tablespace_type property of this TablespaceUsageTrendAggregation.
        :type tablespace_type: str

        :param usage_data:
            The value to assign to the usage_data property of this TablespaceUsageTrendAggregation.
        :type usage_data: list[oci.opsi.models.TablespaceUsageTrend]

        """
        self.swagger_types = {
            'tablespace_name': 'str',
            'tablespace_type': 'str',
            'usage_data': 'list[TablespaceUsageTrend]'
        }

        self.attribute_map = {
            'tablespace_name': 'tablespaceName',
            'tablespace_type': 'tablespaceType',
            'usage_data': 'usageData'
        }

        self._tablespace_name = None
        self._tablespace_type = None
        self._usage_data = None

    @property
    def tablespace_name(self):
        """
        **[Required]** Gets the tablespace_name of this TablespaceUsageTrendAggregation.
        The name of tablespace.


        :return: The tablespace_name of this TablespaceUsageTrendAggregation.
        :rtype: str
        """
        return self._tablespace_name

    @tablespace_name.setter
    def tablespace_name(self, tablespace_name):
        """
        Sets the tablespace_name of this TablespaceUsageTrendAggregation.
        The name of tablespace.


        :param tablespace_name: The tablespace_name of this TablespaceUsageTrendAggregation.
        :type: str
        """
        self._tablespace_name = tablespace_name

    @property
    def tablespace_type(self):
        """
        **[Required]** Gets the tablespace_type of this TablespaceUsageTrendAggregation.
        Type of tablespace


        :return: The tablespace_type of this TablespaceUsageTrendAggregation.
        :rtype: str
        """
        return self._tablespace_type

    @tablespace_type.setter
    def tablespace_type(self, tablespace_type):
        """
        Sets the tablespace_type of this TablespaceUsageTrendAggregation.
        Type of tablespace


        :param tablespace_type: The tablespace_type of this TablespaceUsageTrendAggregation.
        :type: str
        """
        self._tablespace_type = tablespace_type

    @property
    def usage_data(self):
        """
        **[Required]** Gets the usage_data of this TablespaceUsageTrendAggregation.
        List of usage data samples for a tablespace


        :return: The usage_data of this TablespaceUsageTrendAggregation.
        :rtype: list[oci.opsi.models.TablespaceUsageTrend]
        """
        return self._usage_data

    @usage_data.setter
    def usage_data(self, usage_data):
        """
        Sets the usage_data of this TablespaceUsageTrendAggregation.
        List of usage data samples for a tablespace


        :param usage_data: The usage_data of this TablespaceUsageTrendAggregation.
        :type: list[oci.opsi.models.TablespaceUsageTrend]
        """
        self._usage_data = usage_data

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BackendHealth(object):
    """
    The health status of the specified backend server.
    """

    #: A constant which can be used with the status property of a BackendHealth.
    #: This constant has a value of "OK"
    STATUS_OK = "OK"

    #: A constant which can be used with the status property of a BackendHealth.
    #: This constant has a value of "WARNING"
    STATUS_WARNING = "WARNING"

    #: A constant which can be used with the status property of a BackendHealth.
    #: This constant has a value of "CRITICAL"
    STATUS_CRITICAL = "CRITICAL"

    #: A constant which can be used with the status property of a BackendHealth.
    #: This constant has a value of "UNKNOWN"
    STATUS_UNKNOWN = "UNKNOWN"

    def __init__(self, **kwargs):
        """
        Initializes a new BackendHealth object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param status:
            The value to assign to the status property of this BackendHealth.
            Allowed values for this property are: "OK", "WARNING", "CRITICAL", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param health_check_results:
            The value to assign to the health_check_results property of this BackendHealth.
        :type health_check_results: list[oci.network_load_balancer.models.HealthCheckResult]

        """
        self.swagger_types = {
            'status': 'str',
            'health_check_results': 'list[HealthCheckResult]'
        }

        self.attribute_map = {
            'status': 'status',
            'health_check_results': 'healthCheckResults'
        }

        self._status = None
        self._health_check_results = None

    @property
    def status(self):
        """
        **[Required]** Gets the status of this BackendHealth.
        The general health status of the specified backend server.

        *   **OK:**  All health check probes return `OK`

        *   **WARNING:** At least one of the health check probes does not return `OK`

        *   **CRITICAL:** None of the health check probes return `OK`.
        *
        *   **UNKNOWN:** One of the health checks probes return `UNKNOWN`,
        *   or the system is unable to retrieve metrics at this time.

        Allowed values for this property are: "OK", "WARNING", "CRITICAL", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this BackendHealth.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this BackendHealth.
        The general health status of the specified backend server.

        *   **OK:**  All health check probes return `OK`

        *   **WARNING:** At least one of the health check probes does not return `OK`

        *   **CRITICAL:** None of the health check probes return `OK`.
        *
        *   **UNKNOWN:** One of the health checks probes return `UNKNOWN`,
        *   or the system is unable to retrieve metrics at this time.


        :param status: The status of this BackendHealth.
        :type: str
        """
        allowed_values = ["OK", "WARNING", "CRITICAL", "UNKNOWN"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def health_check_results(self):
        """
        **[Required]** Gets the health_check_results of this BackendHealth.
        A list of the most recent health check results returned for the specified backend server.


        :return: The health_check_results of this BackendHealth.
        :rtype: list[oci.network_load_balancer.models.HealthCheckResult]
        """
        return self._health_check_results

    @health_check_results.setter
    def health_check_results(self, health_check_results):
        """
        Sets the health_check_results of this BackendHealth.
        A list of the most recent health check results returned for the specified backend server.


        :param health_check_results: The health_check_results of this BackendHealth.
        :type: list[oci.network_load_balancer.models.HealthCheckResult]
        """
        self._health_check_results = health_check_results

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImportManifest(object):
    """
    Manifest describing details about an import source
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImportManifest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param version:
            The value to assign to the version property of this ImportManifest.
        :type version: str

        :param export_type:
            The value to assign to the export_type property of this ImportManifest.
        :type export_type: str

        :param export_details:
            The value to assign to the export_details property of this ImportManifest.
        :type export_details: object

        :param timestamp:
            The value to assign to the timestamp property of this ImportManifest.
        :type timestamp: datetime

        :param md5:
            The value to assign to the md5 property of this ImportManifest.
        :type md5: str

        :param signature:
            The value to assign to the signature property of this ImportManifest.
        :type signature: str

        """
        self.swagger_types = {
            'version': 'str',
            'export_type': 'str',
            'export_details': 'object',
            'timestamp': 'datetime',
            'md5': 'str',
            'signature': 'str'
        }

        self.attribute_map = {
            'version': 'version',
            'export_type': 'exportType',
            'export_details': 'exportDetails',
            'timestamp': 'timestamp',
            'md5': 'md5',
            'signature': 'signature'
        }

        self._version = None
        self._export_type = None
        self._export_details = None
        self._timestamp = None
        self._md5 = None
        self._signature = None

    @property
    def version(self):
        """
        Gets the version of this ImportManifest.
        the version of the export tool that was used to generate the manifest


        :return: The version of this ImportManifest.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ImportManifest.
        the version of the export tool that was used to generate the manifest


        :param version: The version of this ImportManifest.
        :type: str
        """
        self._version = version

    @property
    def export_type(self):
        """
        Gets the export_type of this ImportManifest.
        the type of application that the export tool was executed against to generate this manifest


        :return: The export_type of this ImportManifest.
        :rtype: str
        """
        return self._export_type

    @export_type.setter
    def export_type(self, export_type):
        """
        Sets the export_type of this ImportManifest.
        the type of application that the export tool was executed against to generate this manifest


        :param export_type: The export_type of this ImportManifest.
        :type: str
        """
        self._export_type = export_type

    @property
    def export_details(self):
        """
        Gets the export_details of this ImportManifest.
        application specific details as parsed from various sources of the application that was exported


        :return: The export_details of this ImportManifest.
        :rtype: object
        """
        return self._export_details

    @export_details.setter
    def export_details(self, export_details):
        """
        Sets the export_details of this ImportManifest.
        application specific details as parsed from various sources of the application that was exported


        :param export_details: The export_details of this ImportManifest.
        :type: object
        """
        self._export_details = export_details

    @property
    def timestamp(self):
        """
        Gets the timestamp of this ImportManifest.
        when this manifest was generated


        :return: The timestamp of this ImportManifest.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this ImportManifest.
        when this manifest was generated


        :param timestamp: The timestamp of this ImportManifest.
        :type: datetime
        """
        self._timestamp = timestamp

    @property
    def md5(self):
        """
        Gets the md5 of this ImportManifest.
        the MD5 hash of the export artifact archive that was produced by the export tool and should be used with this manifest


        :return: The md5 of this ImportManifest.
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """
        Sets the md5 of this ImportManifest.
        the MD5 hash of the export artifact archive that was produced by the export tool and should be used with this manifest


        :param md5: The md5 of this ImportManifest.
        :type: str
        """
        self._md5 = md5

    @property
    def signature(self):
        """
        Gets the signature of this ImportManifest.
        a sha1 hash of all the fields of this manifest (excluding the signature)


        :return: The signature of this ImportManifest.
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """
        Sets the signature of this ImportManifest.
        a sha1 hash of all the fields of this manifest (excluding the signature)


        :param signature: The signature of this ImportManifest.
        :type: str
        """
        self._signature = signature

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Dkim(object):
    """
    The properties that define a DKIM.
    """

    #: A constant which can be used with the lifecycle_state property of a Dkim.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Dkim.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Dkim.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Dkim.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Dkim.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Dkim.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Dkim.
    #: This constant has a value of "NEEDS_ATTENTION"
    LIFECYCLE_STATE_NEEDS_ATTENTION = "NEEDS_ATTENTION"

    #: A constant which can be used with the lifecycle_state property of a Dkim.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new Dkim object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Dkim.
        :type name: str

        :param id:
            The value to assign to the id property of this Dkim.
        :type id: str

        :param email_domain_id:
            The value to assign to the email_domain_id property of this Dkim.
        :type email_domain_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Dkim.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Dkim.
            Allowed values for this property are: "ACTIVE", "CREATING", "DELETING", "DELETED", "FAILED", "INACTIVE", "NEEDS_ATTENTION", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Dkim.
        :type lifecycle_details: str

        :param description:
            The value to assign to the description property of this Dkim.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this Dkim.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Dkim.
        :type time_updated: datetime

        :param dns_subdomain_name:
            The value to assign to the dns_subdomain_name property of this Dkim.
        :type dns_subdomain_name: str

        :param cname_record_value:
            The value to assign to the cname_record_value property of this Dkim.
        :type cname_record_value: str

        :param txt_record_value:
            The value to assign to the txt_record_value property of this Dkim.
        :type txt_record_value: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Dkim.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Dkim.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this Dkim.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'name': 'str',
            'id': 'str',
            'email_domain_id': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'dns_subdomain_name': 'str',
            'cname_record_value': 'str',
            'txt_record_value': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'name': 'name',
            'id': 'id',
            'email_domain_id': 'emailDomainId',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'description': 'description',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'dns_subdomain_name': 'dnsSubdomainName',
            'cname_record_value': 'cnameRecordValue',
            'txt_record_value': 'txtRecordValue',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._name = None
        self._id = None
        self._email_domain_id = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._description = None
        self._time_created = None
        self._time_updated = None
        self._dns_subdomain_name = None
        self._cname_record_value = None
        self._txt_record_value = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Dkim.
        The DKIM selector.
        If the same domain is managed in more than one region, each region must use different selectors.


        :return: The name of this Dkim.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Dkim.
        The DKIM selector.
        If the same domain is managed in more than one region, each region must use different selectors.


        :param name: The name of this Dkim.
        :type: str
        """
        self._name = name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Dkim.
        The `OCID`__ of the DKIM.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Dkim.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Dkim.
        The `OCID`__ of the DKIM.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Dkim.
        :type: str
        """
        self._id = id

    @property
    def email_domain_id(self):
        """
        **[Required]** Gets the email_domain_id of this Dkim.
        The `OCID`__ of the email domain
        that this DKIM belongs to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The email_domain_id of this Dkim.
        :rtype: str
        """
        return self._email_domain_id

    @email_domain_id.setter
    def email_domain_id(self, email_domain_id):
        """
        Sets the email_domain_id of this Dkim.
        The `OCID`__ of the email domain
        that this DKIM belongs to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param email_domain_id: The email_domain_id of this Dkim.
        :type: str
        """
        self._email_domain_id = email_domain_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this Dkim.
        The `OCID`__ of the compartment that contains this DKIM.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Dkim.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Dkim.
        The `OCID`__ of the compartment that contains this DKIM.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Dkim.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Dkim.
        The current state of the DKIM.

        Allowed values for this property are: "ACTIVE", "CREATING", "DELETING", "DELETED", "FAILED", "INACTIVE", "NEEDS_ATTENTION", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Dkim.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Dkim.
        The current state of the DKIM.


        :param lifecycle_state: The lifecycle_state of this Dkim.
        :type: str
        """
        allowed_values = ["ACTIVE", "CREATING", "DELETING", "DELETED", "FAILED", "INACTIVE", "NEEDS_ATTENTION", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Dkim.
        A message describing the current state in more detail.
        For example, can be used to provide actionable information for a resource.


        :return: The lifecycle_details of this Dkim.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Dkim.
        A message describing the current state in more detail.
        For example, can be used to provide actionable information for a resource.


        :param lifecycle_details: The lifecycle_details of this Dkim.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def description(self):
        """
        Gets the description of this Dkim.
        The description of the DKIM. Avoid entering confidential information.


        :return: The description of this Dkim.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Dkim.
        The description of the DKIM. Avoid entering confidential information.


        :param description: The description of this Dkim.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        Gets the time_created of this Dkim.
        The time the DKIM was created.
        Times are expressed in `RFC 3339`__
        timestamp format, \"YYYY-MM-ddThh:mmZ\".

        Example: `2021-02-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Dkim.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Dkim.
        The time the DKIM was created.
        Times are expressed in `RFC 3339`__
        timestamp format, \"YYYY-MM-ddThh:mmZ\".

        Example: `2021-02-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Dkim.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Dkim.
        The time of the last change to the DKIM configuration, due to a state change or
        an update operation.
        Times are expressed in `RFC 3339`__
        timestamp format, \"YYYY-MM-ddThh:mmZ\".

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Dkim.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Dkim.
        The time of the last change to the DKIM configuration, due to a state change or
        an update operation.
        Times are expressed in `RFC 3339`__
        timestamp format, \"YYYY-MM-ddThh:mmZ\".

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Dkim.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def dns_subdomain_name(self):
        """
        Gets the dns_subdomain_name of this Dkim.
        The name of the DNS subdomain that must be provisioned to enable email recipients to verify DKIM signatures.
        It is usually created with a CNAME record set to the cnameRecordValue


        :return: The dns_subdomain_name of this Dkim.
        :rtype: str
        """
        return self._dns_subdomain_name

    @dns_subdomain_name.setter
    def dns_subdomain_name(self, dns_subdomain_name):
        """
        Sets the dns_subdomain_name of this Dkim.
        The name of the DNS subdomain that must be provisioned to enable email recipients to verify DKIM signatures.
        It is usually created with a CNAME record set to the cnameRecordValue


        :param dns_subdomain_name: The dns_subdomain_name of this Dkim.
        :type: str
        """
        self._dns_subdomain_name = dns_subdomain_name

    @property
    def cname_record_value(self):
        """
        Gets the cname_record_value of this Dkim.
        The DNS CNAME record value to provision to the DKIM DNS subdomain, when using the CNAME method for DKIM setup (preferred).


        :return: The cname_record_value of this Dkim.
        :rtype: str
        """
        return self._cname_record_value

    @cname_record_value.setter
    def cname_record_value(self, cname_record_value):
        """
        Sets the cname_record_value of this Dkim.
        The DNS CNAME record value to provision to the DKIM DNS subdomain, when using the CNAME method for DKIM setup (preferred).


        :param cname_record_value: The cname_record_value of this Dkim.
        :type: str
        """
        self._cname_record_value = cname_record_value

    @property
    def txt_record_value(self):
        """
        Gets the txt_record_value of this Dkim.
        The DNS TXT record value to provision to the DKIM DNS subdomain in place of using a CNAME record.
        This is used in cases where a CNAME can not be used, such as when the cnameRecordValue would exceed the maximum length for a DNS entry.
        This can also be used by customers who have an existing procedure to directly provision TXT records for DKIM.
        Be aware that many DNS APIs will require you to break this string into segments of less than 255 characters.


        :return: The txt_record_value of this Dkim.
        :rtype: str
        """
        return self._txt_record_value

    @txt_record_value.setter
    def txt_record_value(self, txt_record_value):
        """
        Sets the txt_record_value of this Dkim.
        The DNS TXT record value to provision to the DKIM DNS subdomain in place of using a CNAME record.
        This is used in cases where a CNAME can not be used, such as when the cnameRecordValue would exceed the maximum length for a DNS entry.
        This can also be used by customers who have an existing procedure to directly provision TXT records for DKIM.
        Be aware that many DNS APIs will require you to break this string into segments of less than 255 characters.


        :param txt_record_value: The txt_record_value of this Dkim.
        :type: str
        """
        self._txt_record_value = txt_record_value

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Dkim.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Dkim.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Dkim.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Dkim.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Dkim.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Dkim.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Dkim.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Dkim.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this Dkim.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this Dkim.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this Dkim.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this Dkim.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectStoreBucket(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    In lieu of a network database link, OCI Object Storage bucket will be used to store Data Pump dump files for the migration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectStoreBucket object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param namespace_name:
            The value to assign to the namespace_name property of this ObjectStoreBucket.
        :type namespace_name: str

        :param bucket_name:
            The value to assign to the bucket_name property of this ObjectStoreBucket.
        :type bucket_name: str

        """
        self.swagger_types = {
            'namespace_name': 'str',
            'bucket_name': 'str'
        }

        self.attribute_map = {
            'namespace_name': 'namespaceName',
            'bucket_name': 'bucketName'
        }

        self._namespace_name = None
        self._bucket_name = None

    @property
    def namespace_name(self):
        """
        **[Required]** Gets the namespace_name of this ObjectStoreBucket.
        Namespace name of the object store bucket.


        :return: The namespace_name of this ObjectStoreBucket.
        :rtype: str
        """
        return self._namespace_name

    @namespace_name.setter
    def namespace_name(self, namespace_name):
        """
        Sets the namespace_name of this ObjectStoreBucket.
        Namespace name of the object store bucket.


        :param namespace_name: The namespace_name of this ObjectStoreBucket.
        :type: str
        """
        self._namespace_name = namespace_name

    @property
    def bucket_name(self):
        """
        **[Required]** Gets the bucket_name of this ObjectStoreBucket.
        Bucket name.


        :return: The bucket_name of this ObjectStoreBucket.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this ObjectStoreBucket.
        Bucket name.


        :param bucket_name: The bucket_name of this ObjectStoreBucket.
        :type: str
        """
        self._bucket_name = bucket_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IssueType(object):
    """
    Details about the issue type associated with the support ticket.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new IssueType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param issue_type_key:
            The value to assign to the issue_type_key property of this IssueType.
        :type issue_type_key: str

        :param label:
            The value to assign to the label property of this IssueType.
        :type label: str

        """
        self.swagger_types = {
            'issue_type_key': 'str',
            'label': 'str'
        }

        self.attribute_map = {
            'issue_type_key': 'issueTypeKey',
            'label': 'label'
        }

        self._issue_type_key = None
        self._label = None

    @property
    def issue_type_key(self):
        """
        Gets the issue_type_key of this IssueType.
        Unique identifier for the issue type.


        :return: The issue_type_key of this IssueType.
        :rtype: str
        """
        return self._issue_type_key

    @issue_type_key.setter
    def issue_type_key(self, issue_type_key):
        """
        Sets the issue_type_key of this IssueType.
        Unique identifier for the issue type.


        :param issue_type_key: The issue_type_key of this IssueType.
        :type: str
        """
        self._issue_type_key = issue_type_key

    @property
    def label(self):
        """
        Gets the label of this IssueType.
        The label for the issue type. For example, `Instance Performance`.


        :return: The label of this IssueType.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this IssueType.
        The label for the issue type. For example, `Instance Performance`.


        :param label: The label of this IssueType.
        :type: str
        """
        self._label = label

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
